@@ -41,6 +41,7 @@ from nipype.interfaces.base import (
 )
 
 from sdcflows.transform import grid_bspline_weights
+from sdcflows.utils.tools import reorient_pedir
 
 
 LOW_MEM_BLOCK_SIZE = 1000
@@ -518,38 +519,38 @@ def _fix_topup_fieldcoeff(in_coeff, fmap_ref, pe_dir, out_file=None):
     from pathlib import Path
     import numpy as np
     import nibabel as nb
-    from sdcflows.utils.tools import ensure_positive_cosines
 
     if out_file is None:
         out_file = Path("coefficients.nii.gz").absolute()
 
-    # Load reference image
     refnii = nb.load(fmap_ref)
-
-    # Load coefficients
     coeffnii = nb.load(in_coeff)
+
+    # Coefficients generated by TOPUP are in LAS space, and we will convert to RAS.
+    # Reorient the reference image and phase-encoding direction to RAS
+    ref_ornt = nb.io_orientation(refnii.affine)
+    refnii_ras = refnii.as_reoriented(ref_ornt)
+    coeff_pe_dir = reorient_pedir(pe_dir, ref_ornt)
+
     # Coefficients - flip LR and overwrite coeffnii variable
     # Internal data orientation of FSL is LAS, so coefficients will be LR flipped,
     # and because the affine does not encode orientation (factors instead), this flip
     # always is implicit.
     # If the PE direction is x/i, the flip in the axis direction causes that the
     # fieldmap estimation must also be inverted in direction (multiply by -1.0)
-    reverse_pe = -1.0 if "i" in pe_dir.replace("x", "i") else 1.0
-    lr_axis = "".join(nb.aff2axcodes(coeffnii.affine)).index("R")
+    reverse_pe = -1.0 if coeff_pe_dir[0] == "i" else 1.0
     coeffnii = coeffnii.__class__(
-        reverse_pe * np.flip(np.asanyarray(coeffnii.dataobj), axis=lr_axis),
+        reverse_pe * np.flip(np.asanyarray(coeffnii.dataobj), axis=0),
         coeffnii.affine,
         coeffnii.header,
     )
-    # Ensure reference has positive director cosines
-    refnii, ref_axcodes = ensure_positive_cosines(refnii)
 
     # Get matrix of B-Spline control knots
     coeff_shape = np.array(coeffnii.shape[:3])
     # Get factors (w.r.t. reference's pixel sizes) to calculate separation btw control points
     factors = np.array(coeffnii.header.get_zooms()[:3])
     # Shape checking
-    ref_shape = np.array(refnii.shape[:3])
+    ref_shape = np.array(refnii_ras.shape[:3])
     exp_shape = ref_shape // factors + 3 * (factors > 1)
     if not np.all(coeff_shape == exp_shape):
         raise ValueError(
@@ -559,8 +560,8 @@ def _fix_topup_fieldcoeff(in_coeff, fmap_ref, pe_dir, out_file=None):
 
     # Contextualize the control points in space with a proper NIfTI affine
     newaff = np.eye(4)
-    newaff[:3, :3] = refnii.affine[:3, :3] * factors
-    c_ref = nb.affines.apply_affine(refnii.affine, 0.5 * (ref_shape - 1))
+    newaff[:3, :3] = refnii_ras.affine[:3, :3] * factors
+    c_ref = nb.affines.apply_affine(refnii_ras.affine, 0.5 * (ref_shape - 1))
     c_coeff = nb.affines.apply_affine(newaff, 0.5 * (coeff_shape - 1))
     newaff[:3, 3] = c_ref - c_coeff
 
@@ -621,18 +622,24 @@ def _b0_resampler(in_file, coeffs, pe, ro, hmc_xfm=None, unwarp=None, newpath=No
     # Load distorted image
     distorted_img = nb.load(in_file)
 
-    if unwarp.fit(distorted_img):
+    # Reorient to RAS to ensure consistency with coefficients
+    # The b-spline weight matrix is sensitive to orientation
+    ornt = nb.io_orientation(distorted_img.affine)
+    distorted_ras = distorted_img.as_reoriented(ornt)
+    pe_ras = reorient_pedir(pe, ornt)
+
+    if unwarp.fit(distorted_ras):
         unwarp.mapped.to_filename(retval[2])
     else:
         retval[2] = None
 
     # Unwarp
-    unwarped_img = unwarp.apply(distorted_img, ro_time=ro, pe_dir=pe)
+    unwarped_img = unwarp.apply(distorted_ras, ro_time=ro, pe_dir=pe_ras)
 
     # Write out to disk
     unwarped_img.to_filename(retval[0])
 
     # Store the corresponding spatial transformation
-    unwarp.to_displacements(ro_time=ro, pe_dir=pe).to_filename(retval[1])
+    unwarp.to_displacements(ro_time=ro, pe_dir=pe_ras).to_filename(retval[1])
 
     return retval
