@@ -27,7 +27,7 @@ from itertools import product
 from contextlib import suppress
 from pathlib import Path
 from typing import Optional, Union, List
-from bids.layout import BIDSLayout
+from bids.layout import BIDSLayout, BIDSFile
 from bids.utils import listify
 
 from .. import fieldmaps as fm
@@ -317,12 +317,20 @@ def find_estimators(
                 B0FieldIdentifier=f'"{b0_id}"',  # Double quotes to match JSON, not Python repr
                 regex_search=True,
             )
-            e = fm.FieldmapEstimation([
-                fm.FieldmapFile(fmap.path, metadata=fmap.get_metadata())
-                for fmap in bare_ids + listed_ids
-            ])
-            _log_debug_estimation(logger, e, layout.root)
-            estimators.append(e)
+            try:
+                e = fm.FieldmapEstimation(
+                    [
+                        fm.FieldmapFile(fmap.path, metadata=fmap.get_metadata())
+                        for fmap in bare_ids + listed_ids
+                    ]
+                )
+            except (ValueError, TypeError) as err:
+                _log_debug_estimator_fail(
+                    logger, b0_id, bare_ids + listed_ids, layout.root, str(err)
+                )
+            else:
+                _log_debug_estimation(logger, e, layout.root)
+                estimators.append(e)
 
     # Step 2. If no B0FieldIdentifiers were found, try several heuristics
     if not estimators:
@@ -355,14 +363,21 @@ def find_estimators(
             )
             dirs = layout.get_directions(**entities)
             if len(dirs) > 1:
-                e = fm.FieldmapEstimation(
-                    [
-                        fm.FieldmapFile(fmap.path, metadata=fmap.get_metadata())
-                        for fmap in layout.get(**{**entities, **{'direction': dirs}})
-                    ]
-                )
-                _log_debug_estimation(logger, e, layout.root)
-                estimators.append(e)
+                fieldmaps = layout.get(**{**entities, **{"direction": dirs}})
+                try:
+                    e = fm.FieldmapEstimation(
+                        [
+                            fm.FieldmapFile(fmap.path, metadata=fmap.get_metadata())
+                            for fmap in fieldmaps
+                        ]
+                    )
+                except ValueError as err:
+                    _log_debug_estimator_fail(
+                        logger, "unnamed PEPOLAR", fieldmaps, layout.root, str(err)
+                    )
+                else:
+                    _log_debug_estimation(logger, e, layout.root)
+                    estimators.append(e)
 
         # At this point, only single-PE _epi files WITH ``IntendedFor`` can
         # be automatically processed.
@@ -392,7 +407,7 @@ def find_estimators(
             for intent in listify(epi_base_md["IntendedFor"]):
                 target = layout.get_file(str(subject_root / intent))
                 if target is None:
-                    logger.debug("Single PE target %s not found", target)
+                    logger.debug("Single PE target %s not found", intent)
                     continue
 
                 logger.debug("Found single PE target %s", target.relpath)
@@ -400,13 +415,22 @@ def find_estimators(
                 # even if the EPI file is IntendedFor multiple
                 estimator_md = epi_base_md.copy()
                 estimator_md["IntendedFor"] = [intent]
-                with suppress(ValueError, TypeError, fm.MetadataError):
+                try:
                     e = fm.FieldmapEstimation(
                         [
                             fm.FieldmapFile(epi_fmap.path, metadata=estimator_md),
                             fm.FieldmapFile(target.path, metadata=target.get_metadata())
                         ]
                     )
+                except (ValueError, TypeError) as err:
+                    _log_debug_estimator_fail(
+                        logger,
+                        "unnamed PEPOLAR",
+                        [epi_fmap, target],
+                        layout.root,
+                        str(err)
+                    )
+                else:
                     _log_debug_estimation(logger, e, layout.root)
                     estimators.append(e)
 
@@ -482,5 +506,24 @@ def _log_debug_estimation(
         "Found %s estimation from %d sources:\n- %s",
         estimation.method.name,
         len(estimation.sources),
-        "\n- ".join([str(s.path.relative_to(bids_root)) for s in estimation.sources]),
+        "\n- ".join(
+            [str(Path(s.path).relative_to(bids_root)) for s in estimation.sources]
+        ),
+    )
+
+
+def _log_debug_estimator_fail(
+    logger: logging.Logger,
+    b0_id: str,
+    files: List[BIDSFile],
+    bids_root: str,
+    message: str
+) -> None:
+    """A helper function to log failures to build an estimator when running with verbosity."""
+    logger.debug(
+        "Failed to construct %s estimation from %d sources:\n- %s\nError: %s",
+        b0_id,
+        len(files),
+        "\n- ".join([str(Path(s.path).relative_to(bids_root)) for s in files]),
+        message,
     )
